==> tailwindcss-0.1.0.tgz: package/lib/generators/borderWidths.js <==
'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _defineClass = require('../util/defineClass');

var _defineClass2 = _interopRequireDefault(_defineClass);

var _defineClasses = require('../util/defineClasses');

var _defineClasses2 = _interopRequireDefault(_defineClasses);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function defaultBorder(width, color) {
  return (0, _defineClasses2.default)({
    'border': {
      'border': `${width} solid ${color}`
    },
    'border-t': {
      'border-top': `${width} solid ${color}`
    },
    'border-r': {
      'border-right': `${width} solid ${color}`
    },
    'border-b': {
      'border-bottom': `${width} solid ${color}`
    },
    'border-l': {
      'border-left': `${width} solid ${color}`
    }
  });
}

function sizedBorder(size, width, color) {
  const style = width == 0 ? '0' : `${width} solid ${color}`;

  return (0, _defineClasses2.default)({
    [`border-${size}`]: {
      'border': `${style}`
    },
    [`border-t-${size}`]: {
      'border-top': `${style}`
    },
    [`border-r-${size}`]: {
      'border-right': `${style}`
    },
    [`border-b-${size}`]: {
      'border-bottom': `${style}`
    },
    [`border-l-${size}`]: {
      'border-left': `${style}`
    }
  });
}

module.exports = function ({ borderWidths, borderColors }) {
  const color = borderColors.default;

  return _lodash2.default.flatten([defaultBorder(borderWidths.default, color), ..._lodash2.default.map(_lodash2.default.omit(borderWidths, 'default'), (width, size) => sizedBorder(size, width, color))]);
};

==> tailwindcss-0.1.6.tgz: package/lib/generators/borderWidths.js <==
'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _defineClasses = require('../util/defineClasses');

var _defineClasses2 = _interopRequireDefault(_defineClasses);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function defaultBorder(width, color) {
  return (0, _defineClasses2.default)({
    border: {
      border: `${width} solid ${color}`
    },
    'border-t': {
      'border-top': `${width} solid ${color}`
    },
    'border-r': {
      'border-right': `${width} solid ${color}`
    },
    'border-b': {
      'border-bottom': `${width} solid ${color}`
    },
    'border-l': {
      'border-left': `${width} solid ${color}`
    }
  });
}

function sizedBorder(size, width, color) {
  const style = width == 0 ? '0' : `${width} solid ${color}`; // eslint-disable-line eqeqeq

  return (0, _defineClasses2.default)({
    [`border-${size}`]: {
      border: `${style}`
    },
    [`border-t-${size}`]: {
      'border-top': `${style}`
    },
    [`border-r-${size}`]: {
      'border-right': `${style}`
    },
    [`border-b-${size}`]: {
      'border-bottom': `${style}`
    },
    [`border-l-${size}`]: {
      'border-left': `${style}`
    }
  });
}

module.exports = function ({ borderWidths, borderColors }) {
  const color = borderColors.default;

  return _lodash2.default.flatten([defaultBorder(borderWidths.default, color), ..._lodash2.default.map(_lodash2.default.omit(borderWidths, 'default'), (width, size) => sizedBorder(size, width, color))]);
};
